.. Copyright (C) 2013-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2014-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`OpenSSH`_ is a secure replacement for ``telnet`` and other remote control
programs. It allows you to connect to remote hosts over a encrypted communication
channel and to perform a variety of tasks. It's also the primary communication channel
used by Ansible.

.. _OpenSSH: https://www.openssh.com/
